@@ -1,5 +1,5 @@
 #
-# $Id: textButton.tcl,v 1.2 1999/04/04 20:34:58 cwg Exp $
+# $Id: textButton.tcl,v 1.3 2000/02/02 19:33:58 valdis Exp $
 #
 # A text widget button that acts like a Button widget.
 # - John Robert LoVerso
@@ -83,7 +83,7 @@ proc TextButtonLeave {w id} {
     #puts "Leave"
     $w tag configure $id -background $tkPriv(background) \
 			-foreground $tkPriv(foreground)
-    $w configure -cursor xterm
+    $w configure -cursor [option get $w cursor Text ]
     set tkPriv(window) ""
     set tkPriv(id) ""
     set tkPriv(cmd) ""
